@@ -100,12 +100,12 @@ torch_hann_window <- function(window_length, periodic=TRUE, dtype=NULL,
 torch_result_type <- function(tensor1, tensor2) {
   
   if (is_torch_tensor(tensor1) && is_torch_tensor(tensor2)) {
-    o <- cpp_torch_namespace_result_type_tensor_Tensor_other_Tensor(
+    o <- cpp_torch_namespace_result_type_other_Tensor_tensor_Tensor(
       tensor1$ptr, 
       tensor2$ptr
     )
   } else if (is_torch_tensor(tensor1) && !is_torch_tensor(tensor2)) {
-    o <- cpp_torch_namespace_result_type_tensor_Tensor_other_Scalar(
+    o <- cpp_torch_namespace_result_type_other_Scalar_tensor_Tensor(
       tensor1$ptr, 
       torch_scalar(tensor2)$ptr
     )
@@ -378,9 +378,10 @@ torch_movedim <- function(self, source, destination) {
 #' @rdname torch_norm
 torch_norm <- function(self, p = 2L, dim, keepdim = FALSE, dtype) {
   
-  if (missing(dim) && missing(dtype))
-    return(.torch_norm(self = self, p = p))
-  
+  if (missing(dtype)) {
+    dtype <- self$dtype
+  }
+    
   p <- Scalar$new(p)
   if (missing(dim) && !missing(dtype)) {
     
@@ -393,10 +394,6 @@ torch_norm <- function(self, p = 2L, dim, keepdim = FALSE, dtype) {
     return(Tensor$new(ptr = o))
   }
   
-  if (missing(dtype)) {
-    dtype <- self$dtype
-  }
-  
   if (is.numeric(unlist(dim))) {
     o <- cpp_torch_namespace_norm_self_Tensor_p_Scalar_dim_IntArrayRef_keepdim_bool_dtype_ScalarType(
       self = self$ptr, p = p$ptr, dim = unlist(dim), keepdim = keepdim, dtype = dtype$ptr
@@ -566,3 +563,31 @@ torch_multinomial <- function(self, num_samples, replacement = FALSE, generator
   with_no_grad({ r$add_(torch_scalar(1L)) })
   r
 }
+
+#' Index torch tensors
+#' 
+#' Helper functions to index tensors.
+#' 
+#' @param self (Tensor) Tensor that will be indexed.
+#' @param indices (`List[Tensor]`) List of indices. Indices are torch tensors with
+#'   `torch_long()` dtype.
+#' 
+#' @name torch_index
+#' @export
+NULL
+
+#' In-place version of `torch_index_put`.
+#' @name torch_index_put_
+#' @inheritParams torch_index
+#' @param values (Tensor) values that will be replaced the indexed location. Used
+#'   for `torch_index_put` and `torch_index_put_`.
+#' @param accumulate (bool) Wether instead of replacing the current values with `values`,
+#'   you want to add them.
+#' @export
+NULL
+
+#' Modify values selected by `indices`.
+#' @inheritParams torch_index_put_
+#' @name torch_index_put 
+#' @export
+NULL
\ No newline at end of file
