@@ -34,7 +34,6 @@ public:
   operator SEXP () const;
 };
 
-
 std::function<void(void*)> tensor_deleter (void* x);
 
 class XPtrTorchTensor : public XPtrTorch {
@@ -50,6 +49,26 @@ public:
   operator SEXP () const;
 };
 
+class XPtrTorchScriptModule : public XPtrTorch {
+public:
+  // TODO rename lantern_JITModule_delete 
+  XPtrTorchScriptModule (void* x) : XPtrTorch(x, lantern_JITModule_delete) {}
+  explicit XPtrTorchScriptModule (std::shared_ptr<void> x) : XPtrTorch(x) {}
+  XPtrTorchScriptModule (const XPtrTorchScriptModule& x): XPtrTorch(x.get_shared()) {}
+  explicit XPtrTorchScriptModule (SEXP x);
+  operator SEXP () const;
+};
+
+class XPtrTorchScriptMethod : public XPtrTorch {
+public:
+  XPtrTorchScriptMethod (void* x) : XPtrTorch(x, lantern_jit_ScriptMethod_delete) {}
+  XPtrTorchScriptMethod (void* x, std::function<void(void* x)> deleter) : XPtrTorch(x, deleter) {}
+  explicit XPtrTorchScriptMethod (std::shared_ptr<void> x) : XPtrTorch(x) {}
+  XPtrTorchScriptMethod (const XPtrTorchScriptMethod& x): XPtrTorch(x.get_shared()) {}
+  explicit XPtrTorchScriptMethod (SEXP x);
+  operator SEXP () const;
+};
+
 class XPtrTorchOptionalTensor : public XPtrTorch {
 public:
   XPtrTorchOptionalTensor (void* x) : XPtrTorch(x, lantern_optional_tensor_delete) {}
@@ -70,7 +89,7 @@ public:
 
 class XPtrTorchOptionalTensorList : public XPtrTorch {
 public:
-  XPtrTorchOptionalTensorList (void* x) : XPtrTorch(x, lantern_TensorList_delete) {}
+  XPtrTorchOptionalTensorList (void* x) : XPtrTorch(x, lantern_OptionalTensorList_delete) {}
   explicit XPtrTorchOptionalTensorList (std::shared_ptr<void> x) : XPtrTorch(x) {}
   XPtrTorchOptionalTensorList (const XPtrTorchTensorList& x) : XPtrTorch(x.get_shared()) {}
   explicit XPtrTorchOptionalTensorList (SEXP x);
@@ -85,6 +104,14 @@ public:
   explicit XPtrTorchIndexTensorList (SEXP x);
 };
 
+class XPtrTorchOptionalIndexTensorList: public XPtrTorch {
+public:
+  XPtrTorchOptionalIndexTensorList (void* x) : XPtrTorch(x, lantern_OptionalTensorList_delete) {}
+  explicit XPtrTorchOptionalIndexTensorList (std::shared_ptr<void> x) : XPtrTorch(x) {}
+  XPtrTorchOptionalIndexTensorList (const XPtrTorchOptionalIndexTensorList& x) : XPtrTorch(x.get_shared()) {}
+  explicit XPtrTorchOptionalIndexTensorList (SEXP x);
+};
+
 class XPtrTorchScalarType : public XPtrTorch {
 public:
   XPtrTorchScalarType (void* x) : XPtrTorch (x, lantern_ScalarType_delete) {}
@@ -160,6 +187,30 @@ public:
   operator SEXP () const;
 };
 
+class XPtrTorchjit_named_parameter_list : public XPtrTorch {
+public:
+  XPtrTorchjit_named_parameter_list (void* x) : XPtrTorch(x, lantern_jit_named_parameter_list_delete) {}
+  explicit XPtrTorchjit_named_parameter_list (std::shared_ptr<void> x) : XPtrTorch(x) {};
+  XPtrTorchjit_named_parameter_list (const XPtrTorchjit_named_parameter_list& x) : XPtrTorch(x.get_shared()) {};
+  operator SEXP () const;
+};
+
+class XPtrTorchjit_named_buffer_list : public XPtrTorch {
+public:
+  XPtrTorchjit_named_buffer_list (void* x) : XPtrTorch(x, lantern_jit_named_buffer_list_delete) {}
+  explicit XPtrTorchjit_named_buffer_list (std::shared_ptr<void> x) : XPtrTorch(x) {};
+  XPtrTorchjit_named_buffer_list (const XPtrTorchjit_named_buffer_list& x) : XPtrTorch(x.get_shared()) {};
+  operator SEXP () const;
+};
+
+class XPtrTorchjit_named_module_list : public XPtrTorch {
+public:
+  XPtrTorchjit_named_module_list (void* x) : XPtrTorch(x, lantern_jit_named_module_list_delete) {}
+  explicit XPtrTorchjit_named_module_list (std::shared_ptr<void> x) : XPtrTorch(x) {};
+  XPtrTorchjit_named_module_list (const XPtrTorchjit_named_module_list& x) : XPtrTorch(x.get_shared()) {};
+  operator SEXP () const;
+};
+
 class XPtrTorchGenerator : public XPtrTorch {
 public:
   XPtrTorchGenerator (void* x) : XPtrTorch(x, lantern_Generator_delete) {}
@@ -189,6 +240,14 @@ public:
   //operator SEXP () const;
 };
 
+class XPtrTorchFunctionPtr : public XPtrTorch {
+public:
+  XPtrTorchFunctionPtr (void* x) : XPtrTorch(x, lantern_FunctionPtr_delete) {}
+  XPtrTorchFunctionPtr (void* x, std::function<void(void*)> deleter) : XPtrTorch(x, deleter) {}
+  explicit XPtrTorchFunctionPtr (std::shared_ptr<void> x) : XPtrTorch(x) {};
+  XPtrTorchFunctionPtr (const XPtrTorchFunctionPtr& x) : XPtrTorch(x.get_shared()) {};
+};
+
 class XPtrTorchIndexIntArrayRef : public XPtrTorch {
 public:
   XPtrTorchIndexIntArrayRef () : XPtrTorch{NULL} {};
@@ -266,6 +325,116 @@ public:
   }
 };
 
+class XPtrTorchvector_string : public XPtrTorch {
+public:
+  XPtrTorchvector_string (void * x) : XPtrTorch(x, lantern_vector_string_delete) {}
+  operator SEXP () const;
+};
+
+class XPtrTorchstring : public XPtrTorch {
+public:
+  XPtrTorchstring (void * x) : XPtrTorch(x, lantern_string_delete) {}
+  XPtrTorchstring (SEXP x);
+  XPtrTorchstring (const XPtrTorchstring& x) : XPtrTorch(x.get_shared()) {};
+  XPtrTorchstring (std::string x) : XPtrTorchstring(lantern_string_new(x.c_str())) {};
+  operator SEXP () const;
+};
+
+class XPtrTorchStack : public XPtrTorch {
+public:
+  XPtrTorchStack (void * x) : XPtrTorch(x, lantern_Stack_delete) {}
+  XPtrTorchStack (void * x, std::function<void(void*)> deleter) : XPtrTorch(x, deleter) {}
+  explicit XPtrTorchStack (std::shared_ptr<void> x) : XPtrTorch(x) {};
+  XPtrTorchStack (SEXP x);
+  operator SEXP () const;
+};
+
+class XPtrTorchIValue : public XPtrTorch {
+public:
+  XPtrTorchIValue (void * x) : XPtrTorch (x, lantern_IValue_delete) {}
+  explicit XPtrTorchIValue (std::shared_ptr<void> x) : XPtrTorch(x) {};
+  XPtrTorchIValue (const XPtrTorchIValue& x) : XPtrTorch(x.get_shared()) {};
+  XPtrTorchIValue (SEXP x);
+  operator SEXP () const;
+};
+
+class XPtrTorchTuple : public XPtrTorch {
+public:
+  XPtrTorchTuple (void * x) : XPtrTorch (x, lantern_jit_Tuple_delete) {}
+  XPtrTorchTuple (const XPtrTorchTuple& x) : XPtrTorch(x.get_shared()) {};
+  XPtrTorchTuple (SEXP x);
+  operator SEXP () const;
+};
+
+class XPtrTorchvector_bool : public XPtrTorch {
+public:
+  XPtrTorchvector_bool (void * x) : XPtrTorch(x, lantern_vector_bool_delete) {}
+  operator SEXP() const;
+  XPtrTorchvector_bool (SEXP x);
+};
+
+class XPtrTorchvector_Scalar : public XPtrTorch {
+public:
+  XPtrTorchvector_Scalar (void * x) : XPtrTorch(x, lantern_vector_Scalar_delete) {}
+  operator SEXP() const;
+  XPtrTorchvector_Scalar (SEXP x);
+  XPtrTorchvector_Scalar (const XPtrTorchvector_Scalar& x) : XPtrTorch(x.get_shared()) {};
+};
+
+class XPtrTorchvector_int64_t : public XPtrTorch {
+public:
+  XPtrTorchvector_int64_t (void* x) : XPtrTorch(x, lantern_vector_int64_t2_delete) {}
+  operator SEXP() const;
+  XPtrTorchvector_int64_t (SEXP x);
+};
+
+class XPtrTorchvector_double : public XPtrTorch {
+public:
+  XPtrTorchvector_double (void* x) : XPtrTorch(x, lantern_vector_double_delete) {}
+  operator SEXP() const;
+  XPtrTorchvector_double (SEXP x);
+};
+
+class XPtrTorchTensorDict : public XPtrTorch {
+public:
+  XPtrTorchTensorDict (void* x) : XPtrTorch(x, lantern_jit_TensorDict_delete) {}
+  XPtrTorchTensorDict (SEXP x);
+};
+
+class XPtrTorchGenericDict : public XPtrTorch {
+public:
+  XPtrTorchGenericDict (void* x) : XPtrTorch(x, lantern_jit_GenericDict_delete) {}
+  operator SEXP() const;
+};
+
+class XPtrTorchGenericList : public XPtrTorch {
+public:
+  XPtrTorchGenericList (void* x) : XPtrTorch(x, lantern_jit_GenericList_delete) {}
+  operator SEXP() const;
+};
+
+class XPtrTorchvector_IValue : public XPtrTorch {
+public:
+  XPtrTorchvector_IValue (void* x) : XPtrTorch(x, lantern_jit_vector_IValue_delete) {}
+  operator SEXP() const;
+};
+
+class XPtrTorchNamedTupleHelper : public XPtrTorch {
+public:
+  XPtrTorchNamedTupleHelper (void* x) : XPtrTorch(x, lantern_NamedTupleHelper_delete) {}
+  XPtrTorchNamedTupleHelper (SEXP x);
+  operator SEXP() const;
+};
+
+class XPtrTorchCompilationUnit : public XPtrTorch {
+public:
+  XPtrTorchCompilationUnit (void * x) : XPtrTorch(x, lantern_CompilationUnit_delete) {}
+  XPtrTorchCompilationUnit (SEXP x);
+  explicit XPtrTorchCompilationUnit (std::shared_ptr<void> x) : XPtrTorch(x) {};
+  XPtrTorchCompilationUnit (const XPtrTorchCompilationUnit& x) : XPtrTorch(x.get_shared()) {};
+  operator SEXP () const;
+};
+
 #include <Rcpp.h>
 
 class XPtrTorchQScheme : public XPtrTorch {
@@ -288,11 +457,6 @@ public:
   XPtrTorchint64_t (void* x) : XPtrTorch(x, lantern_int64_t_delete) {}
 };
 
-class XPtrTorchvector_int64_t : public XPtrTorch {
-public:
-  XPtrTorchvector_int64_t (void* x) : XPtrTorch(x, lantern_vector_int64_t_delete) {}
-};
-
 class XPtrTorchbool : public XPtrTorch {
 public:
   XPtrTorchbool (void* x) : XPtrTorch(x, lantern_bool_delete) {}
@@ -329,31 +493,6 @@ public:
   XPtrTorchStorage (void * x) : XPtrTorch(x, lantern_Storage_delete) {}
 };
 
-class XPtrTorchIValue : public XPtrTorch {
-public:
-  XPtrTorchIValue (void * x) : XPtrTorch (x, lantern_IValue_delete) {}
-};
-
-class XPtrTorchvector_string : public XPtrTorch {
-public:
-  XPtrTorchvector_string (void * x) : XPtrTorch(x, lantern_vector_string_delete) {}
-};
-
-class XPtrTorchstring : public XPtrTorch {
-public:
-  XPtrTorchstring (void * x) : XPtrTorch(x, lantern_string_delete) {}
-};
-
-class XPtrTorchStack : public XPtrTorch {
-public:
-  XPtrTorchStack (void * x) : XPtrTorch(x, lantern_Stack_delete) {}
-};
-
-class XPtrTorchCompilationUnit : public XPtrTorch {
-public:
-  XPtrTorchCompilationUnit (void * x) : XPtrTorch(x, lantern_CompilationUnit_delete) {}
-};
-
 class XPtrTorchJITModule : public XPtrTorch {
 public:
   XPtrTorchJITModule (void * x) : XPtrTorch(x, lantern_JITModule_delete) {}
@@ -364,11 +503,6 @@ public:
   XPtrTorchTraceableFunction (void * x) : XPtrTorch(x, lantern_TraceableFunction_delete) {}
 };
 
-class XPtrTorchvector_bool : public XPtrTorch {
-public:
-  XPtrTorchvector_bool (void * x) : XPtrTorch(x, lantern_vector_bool_delete) {}
-};
-
 class XPtrTorchvector_void : public XPtrTorch {
 public:
   XPtrTorchvector_void (void * x) : XPtrTorch(x, lantern_vector_void_delete) {}
