@@ -29,4 +29,12 @@ SEXP set_xptr_protected(SEXP s, SEXP pro) {
   return R_NilValue;
 }
 
+// [[Rcpp::export]]
+SEXP xptr_address(SEXP s) {
+  check_is_xptr(s);
+  char* buf[20];
+  sprintf((char*) buf, "%p", R_ExternalPtrAddr(s));
+  return Rf_mkString((char*) buf);
+}
+
 
