@@ -31,6 +31,9 @@ expect_optim_works <- function(optim, defaults) {
   
   
   expect_true(as_array(fn()) <= as_array(initial_value)/2)
+  
+  opt$state_dict()
+  
 }
 
 expect_state_is_updated <- function(opt_fn) {
@@ -40,7 +43,17 @@ expect_state_is_updated <- function(opt_fn) {
   y <- 2 * x
   y$backward()
   opt$step()
-  expect_equal(state(opt$param_groups[[1]]$params[[1]])$step, 1)
+  expect_equal(opt$state$get(opt$param_groups[[1]]$params[[1]])$step, 1)
   opt$step()
-  expect_equal(state(opt$param_groups[[1]]$params[[1]])$step, 2)
+  expect_equal(opt$state$get(opt$param_groups[[1]]$params[[1]])$step, 2)
+  
+  state <- opt$state_dict()
+  x2 <- torch_tensor(1, requires_grad = TRUE)
+  opt2 <- opt_fn(x)
+  opt2$load_state_dict(state)
+  
+  for (i in seq_along(opt$state$map)) {
+    expect_equal(opt2$state$map[[i]], opt$state$map[[i]])
+  }
+  
 }
\ No newline at end of file
