@@ -58,12 +58,14 @@ test_that("nn_sequential", {
   expect_equal(output$shape, c(1000, 1))
   expect_length(model$parameters, 4)
   
-  model <- nn_sequential(
-    name = "mynet",
+  my_sequential <- nn_module(inherit = nn_sequential, classname = "mynet")
+  
+  model <- my_sequential(
     nn_linear(10, 100),
     nn_relu(),
     nn_linear(100, 1)
   )
+  
   expect_s3_class(model, "mynet")
   expect_s3_class(model, "nn_module")
 })
@@ -555,3 +557,51 @@ test_that("calling to doesn't modify the requires_grad attribute of a parameter"
   expect_true(!x$weight$requires_grad)
   
 })
+
+test_that("we can subset `nn_sequential`", {
+  
+
+  x <- nn_sequential(
+    nn_relu(),
+    nn_tanh(),
+    nn_relu6(),
+    nn_relu(),
+    nn_tanh()
+  )
+  
+  expect_true(inherits(x[[1]], "nn_relu"))
+  expect_true(inherits(x[[3]], "nn_relu6"))
+
+  y <- x[2:4]
+  expect_true(inherits(y, "nn_sequential"))
+  expect_true(inherits(y[[1]], "nn_tanh"))
+  expect_true(inherits(y[[2]], "nn_relu6"))
+    
+})
+
+test_that("classes are inherited correctly", {
+  
+  nn <- nn_module(
+    classname = "hello",
+    inherit = nn_linear
+  )
+  
+  nn2 <- nn_module(
+    classname = "goodbye",
+    inherit = nn
+  )
+  
+  expect_equal(
+    class(nn), c("hello", "nn_linear", "nn_module", "nn_module_generator")
+  )
+  
+  expect_equal(
+    class(nn2), c("goodbye", "hello", "nn_linear", "nn_module", "nn_module_generator")
+  )
+  
+  n <- nn(10, 10)
+  expect_equal(class(n), c("hello", "nn_linear", "nn_module"))
+  n2 <- nn2(10, 10)
+  expect_equal(class(n2), c("goodbye", "hello", "nn_linear", "nn_module"))
+  
+})
