@@ -76,8 +76,21 @@ cpp_namespace_name <- function(decl) {
   cpp_function_name(decl, "namespace")
 }
 
+dispatch_arguments_from_name <- memoise::memoise(function(name) {
+  methods <- memoised_declarations() %>% keep(~.x$name == name)
+  get_dispatch_arguments(methods)
+})
+
 cpp_function_name <- function(method, type) {
-  arguments <- get_arguments_with_no_default(list(method))
+
+  dispatch_arguments <- dispatch_arguments_from_name(method$name)
+
+  arguments <- method$arguments %>%
+    map_chr(~.x$name)
+
+  # reorder and filter
+  arguments <- dispatch_arguments[dispatch_arguments %in% arguments]
+
   arg_types <- list()
   for (nm in arguments) {
     arg_types[[nm]] <- method$arguments %>%
@@ -124,6 +137,11 @@ cpp_parameter_type <- function(argument) {
     return("XPtrTorchIndexTensorList")
   }
 
+  if (argument$name == "indices" &&
+      argument$dynamic_type == "const c10::List<c10::optional<Tensor>> &") {
+    return("XPtrTorchOptionalIndexTensorList")
+  }
+
   if (argument$dynamic_type == "Tensor" &&
       argument$type == "const c10::optional<Tensor> &") {
     return("XPtrTorchOptionalTensor")
@@ -237,6 +255,10 @@ cpp_parameter_type <- function(argument) {
     declaration <- "XPtrTorch"
   }
 
+  if (argument$dynamic_type == "ArrayRef<Scalar>") {
+    declaration <- "XPtrTorchvector_Scalar"
+  }
+
   declaration
 }
 
@@ -376,6 +398,10 @@ cpp_argument_transform <- function(argument) {
     result <- glue::glue("{argument$name}.get()")
   }
 
+  if (argument$dynamic_type == "ArrayRef<Scalar>") {
+    result <- glue::glue("{argument$name}.get()")
+  }
+
   result
 }
 
@@ -555,19 +581,39 @@ SKIP_R_BINDIND <- c(
   "_test_string_default"
 )
 
+SKIP_CPP_BINDING <- c()
+
 cpp <- function(path) {
 
   decls <-declarations() %>%
     purrr::discard(~.x$name %in% SKIP_R_BINDIND) %>%
     purrr::discard(~.x$name == "range" && length(.x$arguments) == 3)
 
+  pb <- NULL
+
   methods_code <- decls %>%
+    purrr::discard(~.x$name %in% SKIP_CPP_BINDING) %>%
     purrr::keep(~"Tensor" %in% .x$method_of) %>%
-    purrr::map_chr(cpp_method)
+    {
+      pb <<- progress::progress_bar$new(total = length(.), format = "[:bar] :eta")
+      .
+    } %>%
+    purrr::map_chr(function(x) {
+      pb$tick()
+      cpp_method(x)
+    })
 
   namespace_code <- decls %>%
+    purrr::discard(~.x$name %in% SKIP_CPP_BINDING) %>%
     purrr::keep(~"namespace" %in% .x$method_of) %>%
-    purrr::map_chr(cpp_namespace)
+    {
+      pb <<- progress::progress_bar$new(total = length(.), format = "[:bar] :eta")
+      .
+    } %>%
+    purrr::map_chr(function(x) {
+      pb$tick()
+      cpp_namespace(x)
+    })
 
   writeLines(
     c(
